#
# spec file for package ndiswrapper
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ndiswrapper
Version:        1.59
Release:        3.2.1
Summary:        Use Microsoft NDIS Network Drivers for WLAN Cards
License:        GPL-2.0+
Group:          System/Kernel
Url:            http://ndiswrapper.sourceforge.net
Source0:        http://downloads.sourceforge.net/project/ndiswrapper/stable/ndiswrapper-%{version}.tar.gz
Source2:        README.SUSE
Source3:        preamble
Patch1:         ndiswrapper-1.59.diff
Patch2:         ndiswrapper-init_completion.patch
Patch3:         kernel-3.14.patch
Patch4:         ndiswrapper-kernel_3_14.diff
Patch5:         Support-kernel-4.0.patch
Patch6:         Support-kernel-4.2.patch
Patch7:         ndiswrapper-1.59-kernel-4.3.patch
Patch8:         SLE12-SP3-netdev-last_rx-removal.patch
Patch9:         ndiswrapper-replace-dev-trans_start-update-with-help.patch
BuildRequires:  kernel-source
BuildRequires:  kernel-syms
BuildRequires:  module-init-tools
Requires:       ndiswrapper-kmp
Requires:       pciutils
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?is_opensuse}
ExclusiveArch:  %ix86 x86_64
%else
ExclusiveArch:  x86_64
%endif
%suse_kernel_module_package -p %_sourcedir/preamble kdump um debug xen

%description
Some wireless LAN vendors refuse to release hardware specifications or
drivers for their products for operating systems other than Microsoft
Windows. The ndiswrapper project makes it possible to use such hardware
with Linux by means of a loadable kernel module that "wraps around"
NDIS (Windows network driver API) drivers.

%package KMP
Summary:        Use Microsoft NDIS Network Drivers for WLAN Cards
Group:          System/Kernel

%description KMP
Some wireless LAN vendors refuse to release hardware specifications or
drivers for their products for operating systems other than Microsoft
Windows. The ndiswrapper project makes it possible to use such hardware
with Linux by means of a loadable kernel module that "wraps around"
NDIS (Windows network driver API) drivers.

%prep
%setup -q
%patch1
%patch2
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1

cp %{SOURCE2} .
mkdir obj

%build
CFLAGS="%{optflags}" make -C utils
export EXTRA_CFLAGS='-DVERSION=\"%{version}\"'
mkdir -p obj
for flavor in %flavors_to_build; do
  rm -rf obj/$flavor
  cp -r driver obj/$flavor
  make -C /usr/src/linux-obj/%_target_cpu/$flavor modules \
       M=$PWD/obj/$flavor KBUILD=/usr/src/linux-obj/%_target_cpu/$flavor WRAP_WQ=1
done

%install
install -d -m 755 %{buildroot}/sbin %{buildroot}%{_sbindir} \
    %{buildroot}%{_sysconfdir}/ndiswrapper

# Userspace stuff
install -m 755 utils/loadndisdriver %{buildroot}/sbin
install -m 755 utils/ndiswrapper %{buildroot}%{_prefix}/sbin

# Kernel module
export INSTALL_MOD_PATH=%{buildroot}
export INSTALL_MOD_DIR=updates
for flavor in %flavors_to_build; do
     make -C /usr/src/linux-obj/%_target_cpu/$flavor modules_install \
        M=$PWD/obj/$flavor
done

%files
%defattr(-, root, root)
%{_sysconfdir}/ndiswrapper
/sbin/loadndisdriver
%{_sbindir}/ndiswrapper
%doc README README.SUSE AUTHORS ChangeLog

%changelog
* Mon Apr 10 2017 bpoirier@suse.com
- Fix build with the latest SLE12-SP3 that removed netdev->trans_start
  (bsc#1032086):
  ndiswrapper-replace-dev-trans_start-update-with-help.patch
* Mon Apr  3 2017 tiwai@suse.de
- Fix build with the latest SLE12-SP3 that removed netdev->last_rx
  (bsc#1032086):
  SLE12-SP3-netdev-last_rx-removal.patch
* Wed Aug 17 2016 jlee@suse.com
- Sync the patches and spec with OBS:hardware/ndiswrapper (bsc#990186)
- ndiswrapper-kernel_3_14.diff
- ndiswrapper-1.59-kernel-4.3.patch
* Fri Jan 22 2016 ro@suse.de
- add patch kernel-3.14.patch from debian to fix build with
  current kernel (bnc#963210)
- add patch Support-kernel-4.0.patch from debian
- add patch Support-kernel-4.2.patch from debian
* Tue Jun 23 2015 ro@suse.de
- add patch ndiswrapper-init_completion.patch:
  fix build with more recent kernels (12-sp1) (bnc#935750)
* Wed Jan 29 2014 ro@suse.de
- drop i586 from ExclusiveArch as SLE-12 does not build a runnable
  kernel there
* Fri Nov 29 2013 p.drouand@gmail.com
- Update to version 1.59
  * Support for Linux kernels from 2.6.13 to 3.12
  * 32-bit userspace on 64-bit kernel is supported now
  * Fixed kernel hang if loadndisdriver exits with an error
- Removed patchs; fixed on upstream
  * ndiswrapper-1.58-kernel-3.9.patch
  * ndiswrapper-1.58-kernel-3.10.patch
- Adapt ndiswrapper.diff to upstream changes
* Tue Sep 24 2013 idonmez@suse.com
- Update to version 1.58
- Refresh ndiswrapper-1.58-kernel-3.9.patch
- Add ndiswrapper-1.58-kernel-3.10.patch to fix compilation with
  kernel 3.10
* Mon May 20 2013 mhrusecky@suse.cz
- fixed compilation against kernel 3.9 and newer
  * ndiswrapper-1.58-kernel-3.9.patch
  * * daemonize shouldn't be used in threads created by kthread_create
  * * add_taint function API changed
  * * __devexit was abandoned
* Wed Jan  2 2013 idonmez@suse.com
- Pass WRAP_WQ=1 to make to fix kernel 3.7 build
* Fri May 25 2012 idonmez@suse.com
- Fix build for Factory by explicitly defining KBUILD
* Tue May 22 2012 idonmez@suse.com
- Update to v1.58rc1
  * Fixes build with 3.4 kernel
  * No changelog available upstream
* Fri Jan 20 2012 idonmez@suse.com
- Update to v1.57
  * Added support for Linux 2.6.35 - Linux 3.1
  * Kernels as old as 2.6.14 are now supported
  * IW_AUTH_MFP implemented
  * Reserve stack before copying arguments when calling from Windows
    to Linux on x86_64
  * Fixed memory corruption on module unload seen with Atheros and
    Marvell USB devices.
  * Fixed a kernel panic if there are many devices for one driver
    and one fails to initialize.
  * Fixed support for AVM Fritz USB
  * Loading drivers with unknown symbols is disallowed
  * Fixed some memory leaks
  * Memory usage information has been improved
  * Fixed procfs registration if the network device is renamed
  * Added more function stubs
* Wed Sep 21 2011 idonmez@suse.com
- Add ndiswrapper-3.0.patch
  * HAVE_NETDEV_PRIV is gone in kernel 3.0 and netdev_priv is in
    kernel since 2.6.6
* Fri May 27 2011 coolo@novell.com
- update ndiswrapper.diff to what upstream did in SVN
* Tue Mar 22 2011 idoenmez@novell.com
- Add ndiswrapper-2.6.38.patch: patch from upstream to fix
  compilation with 2.6.38 kernel
* Mon Sep 13 2010 coolo@novell.com
- fix the %%build for flavors
* Thu Sep  9 2010 coolo@novell.com
- extracted patch from sourceforge to support 2.6.35
- extracted patch from lkml how to port ioctl file ops for 2.6.36
* Thu Sep  9 2010 coolo@novell.com
- update to 1.56
  * Fixed compilation with 2.6.31 and newer on i386
  * Use /etc/modprobe.d/ndiswrapper.conf, not /etc/modprobe.d/ndiswrapper.
* Mon Nov 23 2009 ro@suse.de
- fix build on i586 (cmpxchg8b seems only exported on x86_64)
- do not build for xen kernel flavour
* Mon Sep  7 2009 beineri@opensuse.org
- fix build with Kernel 2.6.31 on x86
* Mon Aug  3 2009 coolo@novell.com
- update to 1.55
  * Fixed compilation issues with recent kernels
  * Fixed buffer overflows with nickname
  * Compilation issues with 2.6.27 and 2.6.28 fixed
- removing all our patches that are solved upstream
* Sun Aug  2 2009 coolo@novell.com
- convert net_device API to 2.6.31
* Wed Mar 11 2009 hschaa@suse.de
- Remove Makefile.in and use the Makefile shipped in the
  official tarball. This fixes bnc#465931 and should be easier to
  maintain.
* Mon Oct 13 2008 helmut.schaa@gmail.com
- add ndiswrapper-long-essid.patch which fixes bnc#432461
* Thu Aug 28 2008 ro@suse.de
- fix to build on 2.6.27 (ndiswrapper-iwe_info.patch)
- hack around problems with generating _exports.h files
* Thu Aug 28 2008 ro@suse.de
- update to version 1.52
  * Implemented va_list conversion for x86_64, which fixes oops in
  vsprintf() and vsnprintf().
  * Fixed oops on unload if using our workqueue implementation with
  SMP enabled.
  * Don't change the actual thread priority, just pretend it was
  changed.
  * Implemented format string conversion for x86_64, so that Windows
  long is mapped to Linux int.
  * Fixed most sparse warnings.
  * Simplified code and build system to remove already broken
  support for Linux versions prior to 2.6.16.
  * Added .size and .type for all functions in win2lin_stubs.S to
  improve backtrace on x86_64.
  * Fixed rx key authentication sequence number conversion from
  Windows to Linux so WPA authentication doesn't sometimes go into
  re-key auth loop.
* Fri Feb 22 2008 crrodriguez@suse.de
- update to version 1.52
  * Fixed kernel crash when CONFIG_DEBUG_SHIRQ is enabled
  * Compilation issues with current 2.6.25 kernel tree fixed
- loadndisdriver.c was compiled without RPM_OPT_FLAGS
* Wed Dec 26 2007 crrodriguez@suse.de
-update to version 1.51
- ndiswrapper-1.49 crashes kernel, 1.51 works ok [#350735]
- Added support for 2.6.24-rcX kernels
- Fixed issue with changing mac address (with 'ifconfig hw ether ')
- Fixed kernel crash observed with mrv8335 in ad-hoc mode
- Fixed an smp issue that may cause ndiswrapper to stop transmitting packets after a while (noticed with Marvell Pre-N USB driver)
* Mon Nov 12 2007 ro@suse.de
- hack to compile with 2.6.24rc2 (using mandriva patchkit)
* Mon Nov 12 2007 ro@suse.de
- update to version 1.49:
  * If a driver returns invalid MAC address (00:00:00:00:00) when
    queried with OID_802_3_CURRENT_ADDRESS (probably because
    NdisReadNetworkAddress returns NDIS_STATUS_FAILURE?), use
    OID_802_3_PERMANENT_ADDRESS to get the correct address. This is required for
    some atheros devices (e.g., AR5007EG)
  * Fixed a kernel crash with non-preempt kernels (observed with acx111 driver)
  * Preemption, as required by Windows, has been reimplemented. With this,
    ndiswrapper works with RT-preempt and non-preempt kernels
  * Dropped support for 2.4 kernels (and very old 2.6 kernels)
* Thu Oct 18 2007 ro@suse.de
- update to version 1.48:
  * Support for 2.6.23 kernel
  * Disassocation with wpa_supplicant is fixed (earlier, after disassociation,
    the driver and ndiswrapper would be configured differently, requiring
    unloading and reloading of ndiswrapper module)
  * (Re)Association / (Re)Authentication issues with wpa_supplicant with
    2.6.23 kernels fixed
  * Fixed an issue with 64-bit Broadcom drivers that cause ntos_wq worker thread
    to take up all the CPU in some cases
* Wed Jun 13 2007 jg@suse.de
- update to version 1.47:
  * Fixed random (occassional) crash issues with 64-bit drivers
    (observed with Broadcom driver)
  * Fixed compilation issues with version 1.46
* Tue Jun  5 2007 ro@suse.de
- updaet to version 1.46:
  * Fixed crash with large transfers (bug in version 1.45)
  * Fixes 'NOHZ: local_softirq_pending: 08' warnings from tickless
    kernels
  * Fixed issue(s) with RT-preempt enabled kernels
  * Fixed ndiswrapper script to handle installation of Intel 4965AGN
    driver (which apparently works with ndiswrapper)
  * Fixed a warning when SLUB allocator is used
  * Fixed kernel crash with PsCreateSystemThread that manifested with
    sis163u when preempt is enabled
  * Changing MAC address with 'ifconfig <iface> hw ether' should work
    with all drivers now. If MAC address should be changed everytime
    ndiswrapper is loaded, change 'NetworkAddress' setting, as explained
    in wiki entry 'Tips' (earlier 'mac_address' setting was used, but
    that no longer applies)
  * Fixed an issue with some drivers (e.g., sis163u) that would stall
    after working for a while
  * Fixed crashes when removing module with usb devices
  * Fixed issues with Ubuntu kernels (where PREEMPT is not enabled)
  * Issues with combination of DEBUG_PREEMPT and RT-preempt fixed
  * Fixed issues with newer 64-bit Broadcom driver when more than 1GB RAM is
    present
  * Added support for upcoming 2.6.22 kernels
  * Fixed long standing memory allocation issues with some
    drivers, Atheros especially. With this fix, Atheros cards in Macbook
    with Core 2 Duo are known to work
  * The above fix changes core architecture of ndiswrapper and improves
    memory allocation issues with all drivers, as well as executes
    mostly with bottom-half's enabled for better system response and
    performance. Many drivers have been tested to work with these
    changes; however, some drivers may have been broken
  * Added support for Marvell Gigabit ethernet drivers (apparently
    in-kernel sky2 driver has some issues)
  * Yet another smp fix
  * Bug fix related to events (no driver seems to be affected by this)
  * Fixed soft-lockup issue when multiple network devices are used
  * Fixed a bug when unloading driver
  * Fixed issues with recent RT-preempt patch
  * The workaround for large memory allocations (needed by Atheros drivers)
    with 2.6.19+ kernels, introduced in version 1.33, causes soft-lockup
    with smp. This is now fixed.
* Wed Apr  4 2007 lrupp@suse.de
- added module-init-tools to BuildRequires
* Mon Mar 26 2007 jg@suse.de
- update to version 1.39:
  * An smp issue is fixed
  * When initializing a card that supports 802.11a and either 802.11g
    or b, set the mode to 802.11g or b, as 802.11a is far less common
  * Added support for driver for Atheros device with PCI ID 168C:1014
  * Fixed issue with initializing athfmwdl driver (for atheros USB cards)
  * Fixed ndiswrapper script so it installs drivers for certain
    PCMCIA cards (which have bus type 8, instead of 5)
  * Fixed ndiswrapper script (broken since 1.23 for sis163u driver)
  * Implemented full scatter/gather lists (not tested)
  * Implemented support for hardware tcp/ip checksumming (through NDIS)
  * Fixed a bug with scatter/gather. With this rt61 from RaLink and
    VT6655 from VIA drivers transmit data. Other drivers that associated
    but didn't transmit data (e.g., RT8855, Airgo's Gen3 PCI with
    ID 17CB:0002) may also work.
* Wed Jan 17 2007 jg@suse.de
- update to version 1.34:
  * Provide workaround for large memory allocations in interrupt
    context with 2.6.19+ kernels. With this, atheros (and other?)
    drivers don't need kernel to be patched.
* Thu Jan  4 2007 ro@suse.de
- update to version 1.33:
  * Allow large memory allocations in older kernels; with 2.6.19 and newer
    kernels, vmalloc in atomic allocations is not allowed (see 'patches' section
    on project page for workaround on these newer kernels).
  * Added compatability with 2.6.20-rc1 kernel
  * Fixed crash when changing MAC address (with 'ifconfig hw ether')
  * Fixed crash when names of other network device are changed (e.g., by udev)
  * Fixed crashes with shutting down computer without unloading ndiswrapper
    module.
  * Added support for Davicom 9601 USB ethernet device.
  * Fixed ndiswrapper script to show correct device IDs.
  * Yet another fix to ndiswrapper script (to handle file names with upper case
    extensions).
  * Fixed ndiswrapper script to handle INF files properly.
  * Added support for Atheros 5416 (802.11n) chipset.
  * Windows drivers may request firmware to be loaded in either upper or lower
    case (either full name or partially). Instead of using given name, use
    installed name. This fixes firmware loading issue with Airgo networks
    driver.
  * When compiling with 2.6.19-rc2 and possibly next rc(s), compile with
    'make USE_OWN_WQ=1'. Final 2.6.19 may not need this (hopefully).
  * Bug fix to drivers that load binary firmware files (broken in 1.26). This
    fixes issues with Atheros and TI drivers.
  * Atheros PCI driver requests more map registers for DMA than limit specified
    in NDIS. Instead of failing such invalid requests, continue.
  * Removed debug flag in ndiswrapper script
  * When HIGHMEM is enabled, allocate and copy URB buffers only if
    necessary. This prevents memory allocation failures.
* Tue Oct 31 2006 jg@suse.de
- removed debug parameter from perl invocation (bug 215609)
* Thu Oct  5 2006 jg@suse.de
- update to version 1.25:
  * Support for WE-21
  * Bug fixes
  * Devices are recognized when they are inserted, instead of
    registering when module is loaded. With this, new Windows
    drivers can be installed / updated without unloading
    ndiswrapper module, and any number of Windows drivers can be
    installed without overhead.
  * Minor tweaks and optimizations
  * Fixed issues with RT-Preempt patch
  * 64-bit RT2500 USB driver works
* Mon Sep 18 2006 jg@suse.de
- Removed use of uninitialised variable (bug 184410)
* Fri Sep  1 2006 ro@suse.de
- update Makefile.in to fix build on x86_64
* Fri Sep  1 2006 ro@suse.de
- update to version 1.23:
  * Bug fixes to recent changes in 64-bit driver support.
  * ZyDas ZD1211 driver uses interrupt-out URBs, so set them up properly.
  * Bug fixes to Atheros USB driver support.
* Mon Aug  7 2006 jg@suse.de
- update to version 1.22:
  * Added support for Broadcom 802.11n (draft) driver
  * Added support for 64-bit Marvell driver
  * Optimizations for 64-bit drivers
  * If network interface name changes (through udev, ifrename etc),
    ndiswrapper notices it and changes entry in procfs
  * Fix to a bug (in 1.20) that locked up when used with RT2500
    with SMP.
  * RT2500 is supported with 64-bit.
  * Fixes to 64-bit drivers; TI 1450 (used in AVM Fritz) is
    supported with 64-bit.
  * Fix to SMP kernel crash when USB device is unplugged.
  * Calls to Miniport functions with serialized drivers (such as
    RT2500) are serialized, so they should work with SMP.
  * Enable interrupts in IRQ handler; otherwise, some drivers
    (e.g., Marvell 8335) don't work.
  * Kernel crash with changing mac address
    (with 'ifconfig hw ether ...') fixed.
* Thu Jun 29 2006 jg@suse.de
- update to version 1.18:
  * Kernel crash with RT2500 (and possibly other serialized drivers)
    under heavy traffic load fixed.
  * Support for RNDIS driver with Vista drivers for 64-bit added.
  * netpoll support added; with this netconsole can be used with
    ndiswrapper.
  * Suspend/resume improved
  * Memory allocation tracking support added
  * Proper fix for drivers (Atheros PCI and USB drivers) allocating
    large chunk of memory in atomic context.
  * Fix for crash when module is removed with new Atheros USB
    driver, which supports WPA2 and has no firmware driver (athfmwdl).
  * Memory leaks plugged.
  * Plugging/unplugging/rmmod issues fixed; Marvell devices don't
    need to be unplugged before removing module.
  * Added support for Xpeed X400 ADSL adapter.
  * Only wireless devices will be registered as wireless devices to
    kernel; others (e.g., X400 ADSL) will be registered as network
    devices, by default, with wlan%%d.
  * Issues with multicasting fixed.
  * Issues with ZyDas ZD1211 fixed (broken since 1.9 or so).
  * Fixed memory corruption issues, discovered with CONFIG_DEBUG_SLAB.
  * SMP issues fixed; Netgear WG111 USB (Prism54 chipset) works
    with SMP.
  * Association to open networks (without encryption) is supported
    with 'wext' driver interface with wpa_supplicant.
  * Workaround is provided for Atheros driver so large block of
    memory allocated by this driver in atomic context succeed.
  * Sis163 USB driver with version 1.11 failed to associate reliably.
    This is fixed.
  * TI 1450 USB driver failed to initialize card if module is reloaded.
    This is fixed.
  * WPA with TKIP with TI ACX100 driver now works with 'ap_scan=2' in
    wpa_supplicant's configuration file. Driver for D-Link DWL-650+
    has support for WPA with TKIP for this chipset.
  * Added support for non-encrypted networks with wpa_supplicant.
  * Am1772 with WPA and TKIP authenticates reliably now.
  * Added support for WEP with wpa_supplicant through 'wext' driver
    interface. There is no need for 'ndiswrapper' interface with
    wpa_supplicant anymore.
  * Added support for newer RNDIS (USB) cards (e.g., USR5421,
    F5D7051uk, WUSB54GSv2, all based on Broadcom chip). These support
    WPA2, whereas older RNDIS cards support only WPA.
  * Kernel crash when removing USB cards fixed.
  * Fixed performance issues with SMP.
  * Added support for AMD Am1772.
- removed obsolete wep_fix patch
* Tue Apr 11 2006 jg@suse.de
- fixed WEP support when used with wpa_supplicant's 'wext' backend
  (bug 158892)
* Mon Apr 10 2006 agruen@suse.de
- Add preamble `Enhances: kernel-$flavor' workaround to KMP
  sub-packages (156513).
* Wed Mar  8 2006 agruen@suse.de
- The ndiswrapper-kmp-flavor packages provide the ndiswrapper-kmp
  symbol, not ndiswrapper-KMP (155723).
* Tue Mar  7 2006 aj@suse.de
- Require ndiswrapper-KMP [#155723].
* Mon Feb 13 2006 jg@suse.de
- update to version 1.10, changes:
  * Added support for 64-bit USB drivers.
  * Added support for real-time preempt (RT) patch.
  * Added support for TNETW1450 (TI's USB chipset).
  * Added support for latest Windows Broadcom driver.
  * Added support for Airgo Networks MIMO Pre-N driver.
  * Added support for Intel PRO/Wireless 3945ABG driver; this
    driver needs 16KB stacks in kernel.
  * Bug fixes.
* Fri Feb  3 2006 jg@suse.de
- converted to Kernel Module Package
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 jg@suse.de
- update to version 1.8, changes:
  * Issue with WEP with wpa_supplicant fixed (keys must be saved
    and restored).
  * Support for newer kernels added.
  * Crash when removing ndiswrapper module with certain Windows
    drivers fixed.
* Mon Jan  2 2006 jg@suse.de
- Fixed Makefile.in (usb module was missing)
* Thu Dec 22 2005 jg@suse.de
- update to version 1.7, changes:
  * Drivers and driver files are dynamically loaded and unloaded as
    and when necessary; this should save memory.
  * Support for Highmem with USB devices added.
  * Bulk and interrupt URBs were being mixed up in earlier releases
  - this issue is fixed.
  * Crashes due to 'divide by zero' error in update_wireless_stats fixed.
  * Support for Atheros USB drivers, including RangeMAX MIMO,  added.
  * Suspend and resume support improved; USB devices should now be
    able to suspend and resume.
* Tue Nov  8 2005 jg@suse.de
- update to version 1.5, changes:
  * SMP issues fixed.
  * Zero-copy for sending packets implemented.
  * If a device doesn't resume properly (from suspend), de-initialize
    device so it can be initialized later. This fixes issue with
    suspend/resume with Marvell driver.
  * Issues with WUSB11v4 (Ali chipset) fixed.
  * Rtl string functions have been reimplemented.
  * Resume from suspend works with Marvell chipset 8335.
* Thu Oct 27 2005 jg@suse.de
- update to version 1.4, changes:
  * WPA2 support added.
  * Implemented most of IO manager, PnP manager and Obj manager.
  * No need to update utils everytime ndiswrapper is updated but
    only when utils interface changes.
  * USB layer has been rewritten with many fixes; e.g., USB devices
    no longer disconnect unexpectedly.
  * New devices supported: sis162, sis163, ZyDas 1211, Linksys
    WUSB11v4 (with Ali chipset). These are USB devices.
  * Unplugging USB devices without removing ndiswrapper module
    supported.
  * USB devices work with PREEMPT enabled.
  * Separate workqueue is used in 2.6 kernels; this should prevent
    locking up keyboard etc. in case of kernel crash.
  * Support for new kernels added.
  * Many bug fixes.
  * Added support for Inprocomm IPN2220 with 64-bit.
  * Added support for RNDIS USB devices (tested with U.S. Robotics
    USR5420).
  * Issue with unloading module with some drirvers (e.g., sis and
    Inprocomm ipn2220) fixed.
  * Issue with WPA with sis162u, sis163u and ZyDas zd1211 fixed.
* Mon Jul 18 2005 jg@suse.de
- update to version 1.2, changes:
  * Support for NX (no-execute) bit
  * 64-bit Broadcom driver works with HIGHMEM.
  * Implemented I/O manager layer.
  * Many bug fixes
* Fri Mar 11 2005 jg@suse.de
- enabled building on x86_64
* Mon Mar  7 2005 jg@suse.de
- update to version 1.1, changes:
  * Yet another spinlock (re)implementation. We don't use Linux
    spinlocks to implement Windows spinlocks anymore - ndiswrapper
    implements new spinlock functions that use Windows spinlock
    variables directly.
  * Use kmem_cache pools for MDL (aka NDIS_BUFFER) and NDIS_PACKET
    structures which are allocated often. This should reduce memory
    fragmentation.
  * Use MDL functions when initializing ndis_packet while sending
    packets. This fixes crashes with Fedora kernels (and amd64
    driver at least).
  * Memory leak with 64-bit Broadcom driver fixed
  * Crash when module is removed with Marvell driver fixed
  * In some cases, a Windows driver loads successfully, but
    ndiswrapper concludes otherwise. This is fixed.
* Fri Feb 11 2005 jg@suse.de
- added missing object file in Makefile
* Mon Feb  7 2005 jg@suse.de
- update to version 1.1rc1, changes:
  * Don't use spinlocks unless CONFIG_SMP or CONFIG_DEBUG_SPINLOCK
    is enabled.
  * Don't reset Centrino cards during initialization as this seems
    to turns off radio.
  * Set the active/transmit key index as given, instead of assuming
    1 always. This fixes authentication with Cisco routers. This
    should also fix WEP issues when active key used on the router
    is at index > 1.
  * NdisAcquire(Dpr)SpinLock obtains the lock at DISPATCH_LEVEL
    instead of PASSIVE_LEVEL. This fixes PREEMPT and SMP issues
    with some drivers.
  * Issue with Prism54 driver sometimes crashing kernel when
    scanning fixed.
  * WavePlus 1200 chipset supported.
  * Works with some vendor kernels that use different semantcis
    (from vanilla kernels) for PCI/USB register functions.
  * Don't free memory allocated for 'devices' twice (which was
    causing kernel crash) when device registration failed.
  * Don't set infrastructure mode in wpa_associate, which clears
    the keys. With this, WEP should work again with wpa_supplicant.
  * Fix (small) memory leak - free xmit_array when device is removed.
  * Use spinlock when calling any miniport function. This may fix
    some SMP issues.
  * Preliminary support for AMD64 (tested with Broadcom chipset)
  * Dynamic loader support: A driver is loaded only when necessary,
    so even if many drivers are installed or if a driver installs
    many .conf files (e.g., Centrino), only drivers and device
    configurations necessary are loaded.
  * Set RadioState used by Broadcom drivers to 0, instead of 1. This
    turns on radio (although name suggets the other way round).
  * Sends multiple packets (if driver supports it) in each send
    operation for better efficiency
  * Most of the functionality of loader is moved to userspace tool
    loadndisdriver so it is more robust
  * Encryption info is restored during disassociation; this is useful
    if ad-hoc mode is used as psuedo master mode
  * MAC address can be set in .conf files or changed at any
  * Association and disassociation should happen quickly especially
    with wpa_supplicant
* Thu Dec 16 2004 jg@suse.de
- update to version 0.12, changes:
  * Works with Preempt and SMP kernels.
  * WPA-RADIUS is supported.
  * Compiles with kernels > 2.6.9 and swsuspend2
  * USB cards are reset during initialization; they should work
    without having to reset explicitly
  * Some crashes in USB, especially during initialization, are
    fixed.
  * WEP key setting problems fixed.
  * Check for 4K stack size during compilation and issue warning
    if necessary.
  * Bug fixes
* Fri Oct 22 2004 jg@suse.de
- update to version 0.11, changes:
  * Compilation issues with USB are fixed
  * WPA issues fixed
  * Older Prism USB devices supported
  * Suspend/resume of devices with no power management (e.g., TI)
    fixed
  * ndiswrapper script has an option "-d" to install drivers for a
    different device (if the chipset is same)
  * ndiswrapper script lists USB devices and reports status of
    drivers with more understandable messages
  * Lots of bug fixes and improvements
- registering all devices with driver name 'ndiswrapper', so ifup
  scripts have the possibility to recognize ndiswrapper
- fixed sysfs links (device/driver links were missing)
* Tue Oct  5 2004 agruen@suse.de
- Add a README.SUSE.
* Mon Sep 27 2004 agruen@suse.de
- Update to version 0.10.
* Fri Jun 11 2004 agruen@suse.de
- Update to version 0.8.
* Mon Mar 29 2004 agruen@suse.de
- Add missing object file.
* Mon Mar 29 2004 agruen@suse.de
- Fix a thinko: Exporting the module version works for the test
  build, but doesn't help in the binary kernels.
* Sun Mar 28 2004 agruen@suse.de
- Update to version 0.6+CVS.
* Tue Mar  9 2004 agruen@suse.de
- Update to version 0.5 + regparm fix.
* Sat Feb 21 2004 agruen@suse.de
- CVS update.
* Mon Jan 26 2004 ro@suse.de
- create directory before use
* Sun Jan 25 2004 agruen@suse.de
- Remove /etc/modprobe.d from the file list: This is in the
  module-init-tools package now.
* Fri Jan 23 2004 agruen@suse.de
- Only build on i386 non-SMP kernels.
* Sat Jan 17 2004 agruen@suse.de
- Skip building the kernel module on SMP systems.
- Add sysconfig settings and SuSEconfig script.
* Tue Jan 13 2004 agruen@suse.de
- spec file: BuildArch should really be ExclusiveArch.
* Mon Jan 12 2004 agruen@suse.de
- Fix directory ownership for rpm.
* Sun Jan 11 2004 agruen@suse.de
- Initial package.
